pub struct KeyframeSelector {
pub min_parallax: f64,
pub max_overlap: f64,
pub min_tracked: usize,
pub min_frame_gap: usize,
}Expand description
Keyframe selection criteria.
Fields
min_parallax: f64Minimum median parallax (pixels) to insert a new keyframe.
max_overlap: f64Maximum overlap ratio before forcing a new keyframe.
min_tracked: usizeMinimum number of tracked points to consider.
min_frame_gap: usizeMinimum number of frames between keyframes.
Implementations
Sourceimpl KeyframeSelector
impl KeyframeSelector
Sourcepub fn should_insert(
&self,
current_pts: &[[f64; 2]],
prev_kf_pts: &[[f64; 2]],
frames_since_kf: usize,
) -> bool
pub fn should_insert( &self, current_pts: &[[f64; 2]], prev_kf_pts: &[[f64; 2]], frames_since_kf: usize, ) -> bool
Decide whether the current frame should become a keyframe.
current_pts: 2D feature points in the current frame.prev_kf_pts: the same features as seen in the last keyframe.frames_since_kf: number of frames elapsed since the last keyframe.